@@ -35,16 +35,12 @@ from neutron.neutron_api_mappers import SecurityGroupMapper
 from ovndb.db_set_command import DbSetCommand
 import ovndb.acls as acl_lib
 
-WHITE_LIST_GROUP_NAMES = [
-    acl_lib.DEFAULT_PG_NAME, acl_lib.DROP_ALL_IP_PG_NAME
-]
-
 
 def build_add_acl_command(f):
     @wraps(f)
     def build_command_from_dict(wrapped_self, port_group):
         return [
-            wrapped_self.create_add_acl_command(port_group.uuid, acl_data)
+            wrapped_self.create_add_acl_command(port_group.name, acl_data)
             for acl_data in f(wrapped_self, port_group)
         ]
     return build_command_from_dict
@@ -67,7 +63,7 @@ class OvnSecurityGroupApi(object):
             SecurityGroupMapper.OVN_SECURITY_GROUP_CREATE_TS: now,
             SecurityGroupMapper.OVN_SECURITY_GROUP_UPDATE_TS: now,
             SecurityGroupMapper.OVN_SECURITY_GROUP_REV_NUMBER: '1',
-            SecurityGroupMapper.OVN_SECURITY_GROUP_NAME: name,
+            SecurityGroupMapper.OVN_SECURITY_GROUP_NAME: name
         }
         if description:
             external_ids[
@@ -82,7 +78,7 @@ class OvnSecurityGroupApi(object):
                 SecurityGroupMapper.OVN_SECURITY_GROUP_PROJECT
             ] = project_id
         return self._idl.pg_add(
-            pg_name, may_exist=False, external_ids=external_ids
+            pg_name, may_exist=False, acls=[], external_ids=external_ids
         )
 
     def delete_security_group(self, port_group_id):
@@ -113,18 +109,22 @@ class OvnSecurityGroupApi(object):
                 SecurityGroupMapper.OVN_SECURITY_GROUP_DESCRIPTION
             ] = description
 
-        DbSetCommand(
+        return DbSetCommand(
             self._idl, ovnconst.TABLE_PORT_GROUP, sec_group_id
-        ).add(ovnconst.ROW_PG_NAME, pg_name).add(
+        ).add(
+            ovnconst.ROW_PG_NAME, pg_name, add_condition=name is not None
+        ).add(
             ovnconst.ROW_PG_EXTERNAL_IDS,
             external_ids
-        ).execute()
+        ).build_command()
 
     @staticmethod
     def _generate_name_when_required(name):
-        return u'ovirt_{name}_{gen_id}'.format(
-            name=name, gen_id=str(uuid.uuid4()).replace('-', '_')
-        ) if name not in WHITE_LIST_GROUP_NAMES else name
+        return (
+            str(uuid.uuid4())
+            if name not in SecurityGroupMapper.WHITE_LIST_GROUP_NAMES
+            else name
+        )
 
     @staticmethod
     def get_bumped_revision_number(security_group):
@@ -157,7 +157,7 @@ class OvnSecurityGroupApi(object):
     def create_add_acl_command(self, pg_uuid, acl):
         return self._idl.pg_acl_add(
             pg_uuid, acl['direction'], acl['priority'],
-            acl['match'], acl['action'], severity='alert', name='',
+            acl['match'], acl['action'], severity='alert', name=acl['name'],
             **acl.get('external_ids', {})
         )
 
@@ -189,50 +189,11 @@ class OvnSecurityGroupApi(object):
 
     @staticmethod
     def get_default_sec_group_name():
-        return acl_lib.DEFAULT_PG_NAME
+        return SecurityGroupMapper.DEFAULT_PG_NAME
 
     @staticmethod
     def get_drop_all_sec_group_name():
-        return acl_lib.DROP_ALL_IP_PG_NAME
-
-    def create_address_set(self, ip_version, sec_group_name):
-        return self._idl.db_create(
-            ovnconst.TABLE_ADDRESS_SET,
-            name=acl_lib.get_assoc_addr_set_name(
-                sec_group_name, ip_version
-            ),
-            external_ids={'sec_group_name': sec_group_name}
-        )
-
-    def remove_address_set(self, address_set_name):
-        return self._idl.db_destroy(
-            ovnconst.TABLE_ADDRESS_SET, address_set_name
-        )
-
-    def add_address_set_ip(self, security_groups, ip, ip_version):
-        for sec_group in security_groups:
-            addr_set_name = acl_lib.get_assoc_addr_set_name(
-                sec_group.name, ip_version
-            )
-            current_ips = self.get_address_set_addresses(addr_set_name)
-            DbSetCommand(
-                self._idl, ovnconst.TABLE_ADDRESS_SET, addr_set_name
-            ).add('addresses', current_ips + [ip]).execute()
-
-    def get_address_set_addresses(self, addr_set_name):
-        row = self._idl.lookup(ovnconst.TABLE_ADDRESS_SET, addr_set_name)
-        return row.addresses if row else []
-
-    def remove_address_set_ip(self, security_groups, ip, ip_version):
-        for sec_group in security_groups:
-            addr_set_name = acl_lib.get_assoc_addr_set_name(
-                sec_group.name, ip_version
-            )
-            current_ips = self.get_address_set_addresses(addr_set_name)
-            current_ips.remove(ip)
-            DbSetCommand(
-                self._idl, ovnconst.TABLE_ADDRESS_SET, addr_set_name
-            ).add('addresses', current_ips).execute()
+        return SecurityGroupMapper.DROP_ALL_IP_PG_NAME
 
 
 def only_rules_with_allowed_actions(f):
